@@ -110,12 +110,12 @@ protocol.home()
 
 plate = protocol.load_labware('corning_96_wellplate_360ul_flat', 1)
 
-laserController = laser.Controller(protocol=protocol, print_position_in_relative=False)
+laserController = laser.Controller(protocol=protocol, print_debug_messages=False)
 
-laserController.move_to_well(plate["A1"])
+laserController.move_to_well(plate["A1"], speed=100)
 
 print("Moving to start position...")
-laserController.move_z(plate["A1"].top(5).point.z)
+laserController.move_z(plate["A1"].top(5).point.z, speed=100)
 
 
 def updateOffsetsFile(x: float, y: float, z: float):
@@ -167,24 +167,22 @@ def show_or_exit(key):
     if key in movement_distances.keys():
         set_movement_distance(movement_distances[key])
     if key in ("U", "u"):
+        save_offset()
         top_of_well = plate["A1"].top().point
-        laserController.move_to_well(plate["A1"])
-        laserController.move_z(plate["A1"].top(5).point.z)
+        laserController.move_to_well(plate["A1"], speed=100)
+        laserController.move_z(plate["A1"].top(5).point.z, speed=100)
 
     if key in ("I", "i"):
+        save_offset()
         top_of_well = plate["A12"].top().point
-        laserController.move_to_well(plate["A12"])
-        laserController.move_z(plate["A12"].top(5).point.z)
+        laserController.move_to_well(plate["A12"], speed=100)
+        laserController.move_z(plate["A12"].top(5).point.z, speed=100)
 
     if key in ("O", "o"):
-        top_of_well = plate["F1"].top().point
-        laserController.move_to_well(plate["F1"])
-        laserController.move_z(plate["F1"].top(5).point.z)
-
-    if key in ("P", "p"):
-        top_of_well = plate["F12"].top().point
-        laserController.move_to_well(plate["F12"])
-        laserController.move_z(plate["F12"].top(5).point.z)
+        save_offset()
+        top_of_well = plate["H12"].top().point
+        laserController.move_to_well(plate["H12"], speed=100)
+        laserController.move_z(plate["H12"].top(5).point.z, speed=100)
 
     if key in ('h', 'H'):
         protocol.home()
@@ -227,6 +225,9 @@ KEYBOARD SHORTCUTS:
 Number keys - set movement distance: {num_key_expl}
 Arrow keys - move horizontally by movement distance
 Shift + up and down Arrow keys - move vertically by movement distance
+u - move to well A1
+i - move to well A12
+o - move to well H12
 s - save calibration 
 h - home
 q - exit
@@ -234,9 +235,18 @@ q - exit
 
 instructions = urwid.Text(f"""\
 CALIBRATION INSTRUCTIONS
-Place 96 well plate in slot 1
-Move laser mount so that bottom of metal ferule is centered and level with top of well A1
-Press s to save offsets
+1. Place 96 well plate in slot 1
+2. Move laser mount so that bottom of metal ferule is centered and level with top of well A1
+3. press s to save calibration
+4. Press i to move laser mount over A12
+5. Move laser mount so that bottom of metal ferule is centered and level with top of well A12
+6. press s to save calibration
+7. Press o to move laser mount over H12
+8. Move laser mount so that bottom of metal ferule is centered and level with top of well H12
+9. press s to save calibration
+10. Press u to move laser mount over A1 again
+11. press h to home
+12. press q to quit
 """)
 
 blank = urwid.Divider()
